/****************************************************************************
** Meta object code from reading C++ file 'kfileitemmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dolphin-26.07.80/src/kitemviews/kfileitemmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kfileitemmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KFileItemModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KFileItemModel::qt_create_metaobjectdata<qt_meta_tag_ZN14KFileItemModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KFileItemModel",
        "directoryLoadingStarted",
        "",
        "directoryLoadingCompleted",
        "directoryRefreshing",
        "directoryLoadingCanceled",
        "directoryLoadingProgress",
        "percent",
        "directorySortingProgress",
        "infoMessage",
        "message",
        "errorMessage",
        "kioErrorCode",
        "directoryRedirection",
        "QUrl",
        "oldUrl",
        "newUrl",
        "urlIsFileError",
        "url",
        "fileItemsChanged",
        "KFileItemList",
        "changedFileItems",
        "currentDirectoryRemoved",
        "resortAllItems",
        "slotCompleted",
        "slotCanceled",
        "slotItemsAdded",
        "directoryUrl",
        "items",
        "slotItemsDeleted",
        "slotRefreshItems",
        "QList<std::pair<KFileItem,KFileItem>>",
        "slotClear",
        "slotSortingChoiceChanged",
        "slotListerError",
        "KIO::Job*",
        "job",
        "dispatchPendingItemsToInsert"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'directoryLoadingStarted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryLoadingCompleted'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryRefreshing'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryLoadingCanceled'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryLoadingProgress'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'directorySortingProgress'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'infoMessage'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(const QString &, const int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'directoryRedirection'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 14, 16 },
        }}),
        // Signal 'urlIsFileError'
        QtMocHelpers::SignalData<void(const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 18 },
        }}),
        // Signal 'fileItemsChanged'
        QtMocHelpers::SignalData<void(const KFileItemList &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'currentDirectoryRemoved'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resortAllItems'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCompleted'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCanceled'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotItemsAdded'
        QtMocHelpers::SlotData<void(const QUrl &, const KFileItemList &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 27 }, { 0x80000000 | 20, 28 },
        }}),
        // Slot 'slotItemsDeleted'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 28 },
        }}),
        // Slot 'slotRefreshItems'
        QtMocHelpers::SlotData<void(const QList<QPair<KFileItem,KFileItem>> &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 28 },
        }}),
        // Slot 'slotClear'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSortingChoiceChanged'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotListerError'
        QtMocHelpers::SlotData<void(KIO::Job *)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'dispatchPendingItemsToInsert'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KFileItemModel, qt_meta_tag_ZN14KFileItemModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KFileItemModel::staticMetaObject = { {
    QMetaObject::SuperData::link<KItemModelBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KFileItemModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KFileItemModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KFileItemModelE_t>.metaTypes,
    nullptr
} };

void KFileItemModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KFileItemModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->directoryLoadingStarted(); break;
        case 1: _t->directoryLoadingCompleted(); break;
        case 2: _t->directoryRefreshing(); break;
        case 3: _t->directoryLoadingCanceled(); break;
        case 4: _t->directoryLoadingProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->directorySortingProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->infoMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->directoryRedirection((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 9: _t->urlIsFileError((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->fileItemsChanged((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 11: _t->currentDirectoryRemoved(); break;
        case 12: _t->resortAllItems(); break;
        case 13: _t->slotCompleted(); break;
        case 14: _t->slotCanceled(); break;
        case 15: _t->slotItemsAdded((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2]))); break;
        case 16: _t->slotItemsDeleted((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 17: _t->slotRefreshItems((*reinterpret_cast<std::add_pointer_t<QList<std::pair<KFileItem,KFileItem>>>>(_a[1]))); break;
        case 18: _t->slotClear(); break;
        case 19: _t->slotSortingChoiceChanged(); break;
        case 20: _t->slotListerError((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1]))); break;
        case 21: _t->dispatchPendingItemsToInsert(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)()>(_a, &KFileItemModel::directoryLoadingStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)()>(_a, &KFileItemModel::directoryLoadingCompleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)()>(_a, &KFileItemModel::directoryRefreshing, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)()>(_a, &KFileItemModel::directoryLoadingCanceled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)(int )>(_a, &KFileItemModel::directoryLoadingProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)(int )>(_a, &KFileItemModel::directorySortingProgress, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)(const QString & )>(_a, &KFileItemModel::infoMessage, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)(const QString & , const int )>(_a, &KFileItemModel::errorMessage, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)(const QUrl & , const QUrl & )>(_a, &KFileItemModel::directoryRedirection, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)(const QUrl & )>(_a, &KFileItemModel::urlIsFileError, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)(const KFileItemList & )>(_a, &KFileItemModel::fileItemsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFileItemModel::*)()>(_a, &KFileItemModel::currentDirectoryRemoved, 11))
            return;
    }
}

const QMetaObject *KFileItemModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KFileItemModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KFileItemModelE_t>.strings))
        return static_cast<void*>(this);
    return KItemModelBase::qt_metacast(_clname);
}

int KFileItemModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KItemModelBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void KFileItemModel::directoryLoadingStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KFileItemModel::directoryLoadingCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KFileItemModel::directoryRefreshing()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KFileItemModel::directoryLoadingCanceled()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KFileItemModel::directoryLoadingProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KFileItemModel::directorySortingProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KFileItemModel::infoMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KFileItemModel::errorMessage(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void KFileItemModel::directoryRedirection(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void KFileItemModel::urlIsFileError(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KFileItemModel::fileItemsChanged(const KFileItemList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void KFileItemModel::currentDirectoryRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
