/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.DolphinMainWindow.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef DOLPHINMAINWINDOWINTERFACE_H
#define DOLPHINMAINWINDOWINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.dolphin.MainWindow
 */
class OrgKdeDolphinMainWindowInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.dolphin.MainWindow"; }

public:
    OrgKdeDolphinMainWindowInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeDolphinMainWindowInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> activateWindow(const QString &activationToken)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(activationToken);
        return asyncCallWithArgumentList(QStringLiteral("activateWindow"), argumentList);
    }

    inline QDBusPendingReply<bool> isActiveWindow()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isActiveWindow"), argumentList);
    }

    inline QDBusPendingReply<bool> isItemVisibleInAnyView(const QString &urlOfItem)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(urlOfItem);
        return asyncCallWithArgumentList(QStringLiteral("isItemVisibleInAnyView"), argumentList);
    }

    inline QDBusPendingReply<bool> isUrlOpen(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("isUrlOpen"), argumentList);
    }

    inline QDBusPendingReply<> openDirectories(const QStringList &dirs, bool splitView)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(dirs) << QVariant::fromValue(splitView);
        return asyncCallWithArgumentList(QStringLiteral("openDirectories"), argumentList);
    }

    inline QDBusPendingReply<> openFiles(const QStringList &files, bool splitView)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(splitView);
        return asyncCallWithArgumentList(QStringLiteral("openFiles"), argumentList);
    }

    inline QDBusPendingReply<> pasteIntoFolder()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("pasteIntoFolder"), argumentList);
    }

    inline QDBusPendingReply<> quit()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("quit"), argumentList);
    }

    inline QDBusPendingReply<> slotSplitViewChanged()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("slotSplitViewChanged"), argumentList);
    }

    inline QDBusPendingReply<> slotTabBarChanged()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("slotTabBarChanged"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void settingsChanged();
};

namespace org {
  namespace kde {
    namespace dolphin {
      using MainWindow = ::OrgKdeDolphinMainWindowInterface;
    }
  }
}

#endif
