/****************************************************************************
** Meta object code from reading C++ file 'placespanel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dolphin-26.07.80/src/panels/places/placespanel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'placespanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PlacesPanelE_t {};
} // unnamed namespace

template <> constexpr inline auto PlacesPanel::qt_create_metaobjectdata<qt_meta_tag_ZN11PlacesPanelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlacesPanel",
        "errorMessage",
        "",
        "error",
        "storageTearDownRequested",
        "mountPath",
        "storageTearDownExternallyRequested",
        "storageTearDownSuccessful",
        "openInSplitViewRequested",
        "QUrl",
        "url",
        "readSettings",
        "slotConfigureTrash",
        "slotUrlsDropped",
        "dest",
        "QDropEvent*",
        "event",
        "QWidget*",
        "parent",
        "slotContextMenuAboutToShow",
        "QModelIndex",
        "index",
        "QMenu*",
        "menu",
        "slotTearDownRequested",
        "slotTearDownRequestedExternally",
        "udi",
        "slotTearDownDone",
        "Solid::ErrorType",
        "QVariant",
        "errorData",
        "slotRowsInserted",
        "first",
        "last",
        "slotRowsAboutToBeRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'storageTearDownRequested'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'storageTearDownExternallyRequested'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'storageTearDownSuccessful'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openInSplitViewRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'readSettings'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConfigureTrash'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUrlsDropped'
        QtMocHelpers::SlotData<void(const QUrl &, QDropEvent *, QWidget *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 14 }, { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'slotContextMenuAboutToShow'
        QtMocHelpers::SlotData<void(const QModelIndex &, QMenu *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'slotTearDownRequested'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'slotTearDownRequestedExternally'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'slotTearDownDone'
        QtMocHelpers::SlotData<void(const QModelIndex &, Solid::ErrorType, const QVariant &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 28, 3 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'slotRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 18 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 },
        }}),
        // Slot 'slotRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 18 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlacesPanel, qt_meta_tag_ZN11PlacesPanelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlacesPanel::staticMetaObject = { {
    QMetaObject::SuperData::link<KFilePlacesView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlacesPanelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlacesPanelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlacesPanelE_t>.metaTypes,
    nullptr
} };

void PlacesPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlacesPanel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->storageTearDownRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->storageTearDownExternallyRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->storageTearDownSuccessful(); break;
        case 4: _t->openInSplitViewRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->readSettings(); break;
        case 6: _t->slotConfigureTrash(); break;
        case 7: _t->slotUrlsDropped((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[3]))); break;
        case 8: _t->slotContextMenuAboutToShow((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 9: _t->slotTearDownRequested((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->slotTearDownRequestedExternally((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->slotTearDownDone((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Solid::ErrorType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 12: _t->slotRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 13: _t->slotRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Solid::ErrorType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlacesPanel::*)(const QString & )>(_a, &PlacesPanel::errorMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlacesPanel::*)(const QString & )>(_a, &PlacesPanel::storageTearDownRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlacesPanel::*)(const QString & )>(_a, &PlacesPanel::storageTearDownExternallyRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlacesPanel::*)()>(_a, &PlacesPanel::storageTearDownSuccessful, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlacesPanel::*)(const QUrl & )>(_a, &PlacesPanel::openInSplitViewRequested, 4))
            return;
    }
}

const QMetaObject *PlacesPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlacesPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlacesPanelE_t>.strings))
        return static_cast<void*>(this);
    return KFilePlacesView::qt_metacast(_clname);
}

int PlacesPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KFilePlacesView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void PlacesPanel::errorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PlacesPanel::storageTearDownRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PlacesPanel::storageTearDownExternallyRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PlacesPanel::storageTearDownSuccessful()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PlacesPanel::openInSplitViewRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
