/****************************************************************************
** Meta object code from reading C++ file 'dolphinviewcontainer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dolphin-26.07.80/src/dolphinviewcontainer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dolphinviewcontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20DolphinViewContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto DolphinViewContainer::qt_create_metaobjectdata<qt_meta_tag_ZN20DolphinViewContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DolphinViewContainer",
        "showFilterBarChanged",
        "",
        "shown",
        "searchBarVisibilityChanged",
        "visible",
        "selectionModeChanged",
        "enabled",
        "writeStateChanged",
        "isFolderWritable",
        "captionChanged",
        "tabRequested",
        "QUrl",
        "url",
        "activeTabRequested",
        "setUrl",
        "setFilterBarVisible",
        "slotSplitTabDisabled",
        "delayedStatusBarUpdate",
        "updateStatusBar",
        "slotDirectoryLoadingStarted",
        "slotDirectoryLoadingCompleted",
        "slotDirectoryLoadingCanceled",
        "slotUrlIsFileError",
        "slotItemActivated",
        "KFileItem",
        "item",
        "slotItemsActivated",
        "KFileItemList",
        "items",
        "slotfileMiddleClickActivated",
        "showItemInfo",
        "closeFilterBar",
        "setNameFilter",
        "nameFilter",
        "setFilterMode",
        "KFileItemModelFilter::FilterMode",
        "mode",
        "setFilterCaseSensitive",
        "caseSensitive",
        "activate",
        "slotUrlNavigatorLocationAboutToBeChanged",
        "slotUrlNavigatorLocationChanged",
        "slotUrlSelectionRequested",
        "redirect",
        "oldUrl",
        "newUrl",
        "requestFocus",
        "stopDirectoryLoading",
        "slotStatusBarZoomLevelChanged",
        "zoomLevel",
        "slotErrorMessageFromView",
        "message",
        "kioErrorCode",
        "showErrorMessage",
        "slotPlacesModelChanged",
        "slotHiddenFilesShownChanged",
        "showHiddenFiles",
        "slotSortHiddenLastChanged",
        "hiddenLast",
        "slotCurrentDirectoryRemoved",
        "slotOpenUrlFinished",
        "KJob*",
        "job"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showFilterBarChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'searchBarVisibilityChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'selectionModeChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'writeStateChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'captionChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'activeTabRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setFilterBarVisible'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'slotSplitTabDisabled'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'delayedStatusBarUpdate'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDirectoryLoadingStarted'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDirectoryLoadingCompleted'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDirectoryLoadingCanceled'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUrlIsFileError'
        QtMocHelpers::SlotData<void(const QUrl &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotItemActivated'
        QtMocHelpers::SlotData<void(const KFileItem &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'slotItemsActivated'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'slotfileMiddleClickActivated'
        QtMocHelpers::SlotData<void(const KFileItem &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'showItemInfo'
        QtMocHelpers::SlotData<void(const KFileItem &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'closeFilterBar'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setNameFilter'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Slot 'setFilterMode'
        QtMocHelpers::SlotData<void(const KFileItemModelFilter::FilterMode)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'setFilterCaseSensitive'
        QtMocHelpers::SlotData<void(const bool)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 39 },
        }}),
        // Slot 'activate'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUrlNavigatorLocationAboutToBeChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotUrlNavigatorLocationChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotUrlSelectionRequested'
        QtMocHelpers::SlotData<void(const QUrl &)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'redirect'
        QtMocHelpers::SlotData<void(const QUrl &, const QUrl &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 45 }, { 0x80000000 | 12, 46 },
        }}),
        // Slot 'requestFocus'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopDirectoryLoading'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStatusBarZoomLevelChanged'
        QtMocHelpers::SlotData<void(int)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 50 },
        }}),
        // Slot 'slotErrorMessageFromView'
        QtMocHelpers::SlotData<void(const QString &, const int)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 52 }, { QMetaType::Int, 53 },
        }}),
        // Slot 'showErrorMessage'
        QtMocHelpers::SlotData<void(const QString &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 52 },
        }}),
        // Slot 'slotPlacesModelChanged'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotHiddenFilesShownChanged'
        QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 57 },
        }}),
        // Slot 'slotSortHiddenLastChanged'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 59 },
        }}),
        // Slot 'slotCurrentDirectoryRemoved'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenUrlFinished'
        QtMocHelpers::SlotData<void(KJob *)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DolphinViewContainer, qt_meta_tag_ZN20DolphinViewContainerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DolphinViewContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DolphinViewContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DolphinViewContainerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20DolphinViewContainerE_t>.metaTypes,
    nullptr
} };

void DolphinViewContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DolphinViewContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showFilterBarChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->searchBarVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->selectionModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->writeStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->captionChanged(); break;
        case 5: _t->tabRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->activeTabRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->setUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->setFilterBarVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->slotSplitTabDisabled(); break;
        case 10: _t->delayedStatusBarUpdate(); break;
        case 11: _t->updateStatusBar(); break;
        case 12: _t->slotDirectoryLoadingStarted(); break;
        case 13: _t->slotDirectoryLoadingCompleted(); break;
        case 14: _t->slotDirectoryLoadingCanceled(); break;
        case 15: _t->slotUrlIsFileError((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 16: _t->slotItemActivated((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 17: _t->slotItemsActivated((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 18: _t->slotfileMiddleClickActivated((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 19: _t->showItemInfo((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 20: _t->closeFilterBar(); break;
        case 21: _t->setNameFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->setFilterMode((*reinterpret_cast<std::add_pointer_t<KFileItemModelFilter::FilterMode>>(_a[1]))); break;
        case 23: _t->setFilterCaseSensitive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->activate(); break;
        case 25: _t->slotUrlNavigatorLocationAboutToBeChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 26: _t->slotUrlNavigatorLocationChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 27: _t->slotUrlSelectionRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 28: _t->redirect((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 29: _t->requestFocus(); break;
        case 30: _t->stopDirectoryLoading(); break;
        case 31: _t->slotStatusBarZoomLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->slotErrorMessageFromView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 33: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->slotPlacesModelChanged(); break;
        case 35: _t->slotHiddenFilesShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->slotSortHiddenLastChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->slotCurrentDirectoryRemoved(); break;
        case 38: _t->slotOpenUrlFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DolphinViewContainer::*)(bool )>(_a, &DolphinViewContainer::showFilterBarChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinViewContainer::*)(bool )>(_a, &DolphinViewContainer::searchBarVisibilityChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinViewContainer::*)(bool )>(_a, &DolphinViewContainer::selectionModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinViewContainer::*)(bool )>(_a, &DolphinViewContainer::writeStateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinViewContainer::*)()>(_a, &DolphinViewContainer::captionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinViewContainer::*)(const QUrl & )>(_a, &DolphinViewContainer::tabRequested, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinViewContainer::*)(const QUrl & )>(_a, &DolphinViewContainer::activeTabRequested, 6))
            return;
    }
}

const QMetaObject *DolphinViewContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DolphinViewContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DolphinViewContainerE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int DolphinViewContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void DolphinViewContainer::showFilterBarChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DolphinViewContainer::searchBarVisibilityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DolphinViewContainer::selectionModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DolphinViewContainer::writeStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DolphinViewContainer::captionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DolphinViewContainer::tabRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DolphinViewContainer::activeTabRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
