/****************************************************************************
** Meta object code from reading C++ file 'dolphinviewactionhandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dolphin-26.07.80/src/views/dolphinviewactionhandler.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dolphinviewactionhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24DolphinViewActionHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto DolphinViewActionHandler::qt_create_metaobjectdata<qt_meta_tag_ZN24DolphinViewActionHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DolphinViewActionHandler",
        "actionBeingHandled",
        "",
        "createDirectoryTriggered",
        "createFileTriggered",
        "selectionModeChangeTriggered",
        "enabled",
        "SelectionMode::BottomBar::Contents",
        "bottomBarContents",
        "updateViewActions",
        "slotViewModeActionTriggered",
        "QAction*",
        "slotRename",
        "slotTrashActivated",
        "slotDeleteItems",
        "togglePreview",
        "slotPreviewsShownChanged",
        "shown",
        "zoomIn",
        "zoomOut",
        "zoomReset",
        "toggleSortFoldersFirst",
        "slotSortOrderChanged",
        "Qt::SortOrder",
        "order",
        "slotSortFoldersFirstChanged",
        "foldersFirst",
        "toggleSortHiddenLast",
        "slotSortHiddenLastChanged",
        "hiddenLast",
        "slotSortRoleChanged",
        "role",
        "slotZoomLevelChanged",
        "current",
        "previous",
        "toggleVisibleRole",
        "action",
        "slotSortTriggered",
        "slotVisibleRolesChanged",
        "QList<QByteArray>",
        "slotGroupByTriggered",
        "slotGroupedSortingChanged",
        "groupedSorting",
        "slotGroupRoleChanged",
        "toggleShowHiddenFiles",
        "slotHiddenFilesShownChanged",
        "slotWriteStateChanged",
        "isFolderWritable",
        "slotAdjustViewProperties",
        "slotDuplicate",
        "slotProperties",
        "slotCopyPath",
        "slotSelectionChanged",
        "KFileItemList",
        "selection",
        "restoreViewSettingsToDefaults"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'actionBeingHandled'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'createDirectoryTriggered'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'createFileTriggered'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionModeChangeTriggered'
        QtMocHelpers::SignalData<void(bool, SelectionMode::BottomBar::Contents)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'selectionModeChangeTriggered'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'updateViewActions'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotViewModeActionTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'slotRename'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTrashActivated'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteItems'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'togglePreview'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotPreviewsShownChanged'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomReset'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleSortFoldersFirst'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSortOrderChanged'
        QtMocHelpers::SlotData<void(Qt::SortOrder)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'slotSortFoldersFirstChanged'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'toggleSortHiddenLast'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSortHiddenLastChanged'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'slotSortRoleChanged'
        QtMocHelpers::SlotData<void(const QByteArray &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 31 },
        }}),
        // Slot 'slotZoomLevelChanged'
        QtMocHelpers::SlotData<void(int, int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 }, { QMetaType::Int, 34 },
        }}),
        // Slot 'toggleVisibleRole'
        QtMocHelpers::SlotData<void(QAction *)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 36 },
        }}),
        // Slot 'slotSortTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'slotVisibleRolesChanged'
        QtMocHelpers::SlotData<void(const QList<QByteArray> &, const QList<QByteArray> &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 33 }, { 0x80000000 | 39, 34 },
        }}),
        // Slot 'slotGroupByTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 36 },
        }}),
        // Slot 'slotGroupedSortingChanged'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'slotGroupRoleChanged'
        QtMocHelpers::SlotData<void(const QByteArray &)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 31 },
        }}),
        // Slot 'toggleShowHiddenFiles'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotHiddenFilesShownChanged'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'slotWriteStateChanged'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
        // Slot 'slotAdjustViewProperties'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDuplicate'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotProperties'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyPath'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'restoreViewSettingsToDefaults'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DolphinViewActionHandler, qt_meta_tag_ZN24DolphinViewActionHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DolphinViewActionHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DolphinViewActionHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DolphinViewActionHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24DolphinViewActionHandlerE_t>.metaTypes,
    nullptr
} };

void DolphinViewActionHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DolphinViewActionHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->actionBeingHandled(); break;
        case 1: _t->createDirectoryTriggered(); break;
        case 2: _t->createFileTriggered(); break;
        case 3: _t->selectionModeChangeTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SelectionMode::BottomBar::Contents>>(_a[2]))); break;
        case 4: _t->selectionModeChangeTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->updateViewActions(); break;
        case 6: _t->slotViewModeActionTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 7: _t->slotRename(); break;
        case 8: _t->slotTrashActivated(); break;
        case 9: _t->slotDeleteItems(); break;
        case 10: _t->togglePreview((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->slotPreviewsShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->zoomIn(); break;
        case 13: _t->zoomOut(); break;
        case 14: _t->zoomReset(); break;
        case 15: _t->toggleSortFoldersFirst(); break;
        case 16: _t->slotSortOrderChanged((*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[1]))); break;
        case 17: _t->slotSortFoldersFirstChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->toggleSortHiddenLast(); break;
        case 19: _t->slotSortHiddenLastChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->slotSortRoleChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 21: _t->slotZoomLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 22: _t->toggleVisibleRole((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 23: _t->slotSortTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 24: _t->slotVisibleRolesChanged((*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2]))); break;
        case 25: _t->slotGroupByTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 26: _t->slotGroupedSortingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->slotGroupRoleChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 28: _t->toggleShowHiddenFiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->slotHiddenFilesShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->slotWriteStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->slotAdjustViewProperties(); break;
        case 32: _t->slotDuplicate(); break;
        case 33: _t->slotProperties(); break;
        case 34: _t->slotCopyPath(); break;
        case 35: _t->slotSelectionChanged((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 36: _t->restoreViewSettingsToDefaults(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DolphinViewActionHandler::*)()>(_a, &DolphinViewActionHandler::actionBeingHandled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinViewActionHandler::*)()>(_a, &DolphinViewActionHandler::createDirectoryTriggered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinViewActionHandler::*)()>(_a, &DolphinViewActionHandler::createFileTriggered, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinViewActionHandler::*)(bool , SelectionMode::BottomBar::Contents )>(_a, &DolphinViewActionHandler::selectionModeChangeTriggered, 3))
            return;
    }
}

const QMetaObject *DolphinViewActionHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DolphinViewActionHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DolphinViewActionHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DolphinViewActionHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    return _id;
}

// SIGNAL 0
void DolphinViewActionHandler::actionBeingHandled()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DolphinViewActionHandler::createDirectoryTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DolphinViewActionHandler::createFileTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DolphinViewActionHandler::selectionModeChangeTriggered(bool _t1, SelectionMode::BottomBar::Contents _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
