/****************************************************************************
** Meta object code from reading C++ file 'dolphinview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dolphin-26.07.80/src/views/dolphinview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dolphinview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DolphinViewE_t {};
} // unnamed namespace

template <> constexpr inline auto DolphinView::qt_create_metaobjectdata<qt_meta_tag_ZN11DolphinViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DolphinView",
        "activated",
        "",
        "urlChanged",
        "QUrl",
        "url",
        "itemActivated",
        "KFileItem",
        "item",
        "requestPropertyDialog",
        "fileMiddleClickActivated",
        "itemsActivated",
        "KFileItemList",
        "items",
        "itemCountChanged",
        "tabRequested",
        "activeTabRequested",
        "windowRequested",
        "modeChanged",
        "DolphinView::Mode",
        "current",
        "previous",
        "previewsShownChanged",
        "shown",
        "hiddenFilesShownChanged",
        "groupedSortingChanged",
        "groupedSorting",
        "statusBarTextChanged",
        "statusBarText",
        "sortRoleChanged",
        "role",
        "groupRoleChanged",
        "sortOrderChanged",
        "Qt::SortOrder",
        "order",
        "sortFoldersFirstChanged",
        "foldersFirst",
        "sortHiddenLastChanged",
        "hiddenLast",
        "visibleRolesChanged",
        "QList<QByteArray>",
        "zoomLevelChanged",
        "requestItemInfo",
        "selectionChanged",
        "selection",
        "requestContextMenu",
        "QPoint",
        "pos",
        "selectedItems",
        "infoMessage",
        "msg",
        "errorMessage",
        "message",
        "kioErrorCode",
        "operationCompletedMessage",
        "showTypeAheadFeedback",
        "typeAheadFeedback",
        "directoryLoadingStarted",
        "directoryLoadingCompleted",
        "directoryLoadingCanceled",
        "directoryLoadingProgress",
        "percent",
        "directorySortingProgress",
        "redirection",
        "oldUrl",
        "newUrl",
        "urlIsFileError",
        "writeStateChanged",
        "isFolderWritable",
        "goBackRequested",
        "goForwardRequested",
        "selectionModeChangeRequested",
        "enabled",
        "toggleActiveViewRequested",
        "urlActivated",
        "goUpRequested",
        "fileItemsChanged",
        "changedFileItems",
        "currentDirectoryRemoved",
        "clickViewBackground",
        "Qt::MouseButton",
        "button",
        "doubleClickViewBackground",
        "viewSettingsChanged",
        "isDefault",
        "reload",
        "setUrl",
        "selectAll",
        "invertSelection",
        "clearSelection",
        "renameSelectedItems",
        "trashSelectedItems",
        "deleteSelectedItems",
        "cutSelectedItemsToClipboard",
        "copySelectedItemsToClipboard",
        "copySelectedItems",
        "destinationUrl",
        "moveSelectedItems",
        "paste",
        "pasteIntoFolder",
        "copyPathToClipboard",
        "duplicateSelectedItems",
        "dropUrls",
        "destUrl",
        "QDropEvent*",
        "dropEvent",
        "QWidget*",
        "dropWidget",
        "stopLoading",
        "updateViewState",
        "isViewSettingsDefaults",
        "restoreViewSettingsToDefaults",
        "activate",
        "slotItemActivated",
        "index",
        "slotItemsActivated",
        "KItemSet",
        "indexes",
        "slotItemMiddleClicked",
        "slotItemContextMenuRequested",
        "QPointF",
        "slotViewContextMenuRequested",
        "slotHeaderContextMenuRequested",
        "slotHeaderColumnWidthChangeFinished",
        "slotSidePaddingWidthChanged",
        "leftPaddingWidth",
        "rightPaddingWidth",
        "slotItemHovered",
        "slotItemUnhovered",
        "slotItemDropEvent",
        "QGraphicsSceneDragDropEvent*",
        "event",
        "slotModelChanged",
        "KItemModelBase*",
        "slotMouseButtonPressed",
        "itemIndex",
        "Qt::MouseButtons",
        "buttons",
        "slotSelectedItemTextPressed",
        "slotItemCreatedFromJob",
        "KIO::Job*",
        "to",
        "slotItemLinkCreatedFromJob",
        "slotIncreaseZoom",
        "slotDecreaseZoom",
        "slotSwipeUp",
        "slotItemCreated",
        "slotJobResult",
        "KJob*",
        "job",
        "slotSelectionChanged",
        "emitSelectionChangedSignal",
        "slotStatJobResult",
        "updateSortFoldersFirst",
        "updateDefaultZoomLevel",
        "updateSortHiddenLast",
        "slotDeleteFileFinished",
        "slotTrashFileFinished",
        "slotRenamingResult",
        "slotDirectoryLoadingStarted",
        "slotDirectoryLoadingCompleted",
        "slotDirectoryLoadingCanceled",
        "slotItemsChanged",
        "slotSortOrderChangedByHeader",
        "slotSortRoleChangedByHeader",
        "slotVisibleRolesChangedByHeader",
        "slotRoleEditingCanceled",
        "slotRoleEditingFinished",
        "QVariant",
        "value",
        "observeCreatedItem",
        "observeCreatedDirectory",
        "selectNextItem",
        "slotDirectoryRedirection",
        "slotTwoClicksRenamingTimerTimeout",
        "onDirectoryLoadingCompletedAfterJob"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'itemActivated'
        QtMocHelpers::SignalData<void(const KFileItem &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'requestPropertyDialog'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileMiddleClickActivated'
        QtMocHelpers::SignalData<void(const KFileItem &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'itemsActivated'
        QtMocHelpers::SignalData<void(const KFileItemList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'itemCountChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'activeTabRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'windowRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void(DolphinView::Mode, DolphinView::Mode)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 19, 21 },
        }}),
        // Signal 'previewsShownChanged'
        QtMocHelpers::SignalData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'hiddenFilesShownChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'groupedSortingChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Signal 'statusBarTextChanged'
        QtMocHelpers::SignalData<void(QString)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Signal 'sortRoleChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 30 },
        }}),
        // Signal 'groupRoleChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 30 },
        }}),
        // Signal 'sortOrderChanged'
        QtMocHelpers::SignalData<void(Qt::SortOrder)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Signal 'sortFoldersFirstChanged'
        QtMocHelpers::SignalData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Signal 'sortHiddenLastChanged'
        QtMocHelpers::SignalData<void(bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Signal 'visibleRolesChanged'
        QtMocHelpers::SignalData<void(const QList<QByteArray> &, const QList<QByteArray> &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 20 }, { 0x80000000 | 40, 21 },
        }}),
        // Signal 'zoomLevelChanged'
        QtMocHelpers::SignalData<void(int, int)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Signal 'requestItemInfo'
        QtMocHelpers::SignalData<void(const KFileItem &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(const KFileItemList &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 44 },
        }}),
        // Signal 'requestContextMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItem &, const KFileItemList &, const QUrl &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 47 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 12, 48 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'infoMessage'
        QtMocHelpers::SignalData<void(const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 50 },
        }}),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(const QString &, const int)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 52 }, { QMetaType::Int, 53 },
        }}),
        // Signal 'operationCompletedMessage'
        QtMocHelpers::SignalData<void(const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 50 },
        }}),
        // Signal 'showTypeAheadFeedback'
        QtMocHelpers::SignalData<void(const QString &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 56 },
        }}),
        // Signal 'directoryLoadingStarted'
        QtMocHelpers::SignalData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryLoadingCompleted'
        QtMocHelpers::SignalData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryLoadingCanceled'
        QtMocHelpers::SignalData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryLoadingProgress'
        QtMocHelpers::SignalData<void(int)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Signal 'directorySortingProgress'
        QtMocHelpers::SignalData<void(int)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Signal 'redirection'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 64 }, { 0x80000000 | 4, 65 },
        }}),
        // Signal 'urlIsFileError'
        QtMocHelpers::SignalData<void(const QUrl &)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'writeStateChanged'
        QtMocHelpers::SignalData<void(bool)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 68 },
        }}),
        // Signal 'goBackRequested'
        QtMocHelpers::SignalData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goForwardRequested'
        QtMocHelpers::SignalData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionModeChangeRequested'
        QtMocHelpers::SignalData<void(bool)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 72 },
        }}),
        // Signal 'toggleActiveViewRequested'
        QtMocHelpers::SignalData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlActivated'
        QtMocHelpers::SignalData<void(const QUrl &)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'goUpRequested'
        QtMocHelpers::SignalData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileItemsChanged'
        QtMocHelpers::SignalData<void(const KFileItemList &)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 77 },
        }}),
        // Signal 'currentDirectoryRemoved'
        QtMocHelpers::SignalData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clickViewBackground'
        QtMocHelpers::SignalData<void(Qt::MouseButton)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 80, 81 },
        }}),
        // Signal 'doubleClickViewBackground'
        QtMocHelpers::SignalData<void(Qt::MouseButton)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 80, 81 },
        }}),
        // Signal 'viewSettingsChanged'
        QtMocHelpers::SignalData<void(bool)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 84 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'invertSelection'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'renameSelectedItems'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'trashSelectedItems'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteSelectedItems'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cutSelectedItemsToClipboard'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copySelectedItemsToClipboard'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copySelectedItems'
        QtMocHelpers::SlotData<void(const KFileItemList &, const QUrl &)>(95, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 44 }, { 0x80000000 | 4, 96 },
        }}),
        // Slot 'moveSelectedItems'
        QtMocHelpers::SlotData<void(const KFileItemList &, const QUrl &)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 44 }, { 0x80000000 | 4, 96 },
        }}),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pasteIntoFolder'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyPathToClipboard'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'duplicateSelectedItems'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dropUrls'
        QtMocHelpers::SlotData<void(const QUrl &, QDropEvent *, QWidget *)>(102, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 103 }, { 0x80000000 | 104, 105 }, { 0x80000000 | 106, 107 },
        }}),
        // Slot 'stopLoading'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateViewState'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'isViewSettingsDefaults'
        QtMocHelpers::SlotData<bool() const>(110, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'restoreViewSettingsToDefaults'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activate'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotItemActivated'
        QtMocHelpers::SlotData<void(int)>(113, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 114 },
        }}),
        // Slot 'slotItemsActivated'
        QtMocHelpers::SlotData<void(const KItemSet &)>(115, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 116, 117 },
        }}),
        // Slot 'slotItemMiddleClicked'
        QtMocHelpers::SlotData<void(int)>(118, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 114 },
        }}),
        // Slot 'slotItemContextMenuRequested'
        QtMocHelpers::SlotData<void(int, const QPointF &)>(119, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 114 }, { 0x80000000 | 120, 47 },
        }}),
        // Slot 'slotViewContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPointF &)>(121, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 120, 47 },
        }}),
        // Slot 'slotHeaderContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPointF &)>(122, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 120, 47 },
        }}),
        // Slot 'slotHeaderColumnWidthChangeFinished'
        QtMocHelpers::SlotData<void(const QByteArray &, qreal)>(123, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 30 }, { QMetaType::QReal, 20 },
        }}),
        // Slot 'slotSidePaddingWidthChanged'
        QtMocHelpers::SlotData<void(qreal, qreal)>(124, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 125 }, { QMetaType::QReal, 126 },
        }}),
        // Slot 'slotItemHovered'
        QtMocHelpers::SlotData<void(int)>(127, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 114 },
        }}),
        // Slot 'slotItemUnhovered'
        QtMocHelpers::SlotData<void(int)>(128, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 114 },
        }}),
        // Slot 'slotItemDropEvent'
        QtMocHelpers::SlotData<void(int, QGraphicsSceneDragDropEvent *)>(129, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 114 }, { 0x80000000 | 130, 131 },
        }}),
        // Slot 'slotModelChanged'
        QtMocHelpers::SlotData<void(KItemModelBase *, KItemModelBase *)>(132, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 133, 20 }, { 0x80000000 | 133, 21 },
        }}),
        // Slot 'slotMouseButtonPressed'
        QtMocHelpers::SlotData<void(int, Qt::MouseButtons)>(134, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 135 }, { 0x80000000 | 136, 137 },
        }}),
        // Slot 'slotSelectedItemTextPressed'
        QtMocHelpers::SlotData<void(int)>(138, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 114 },
        }}),
        // Slot 'slotItemCreatedFromJob'
        QtMocHelpers::SlotData<void(KIO::Job *, const QUrl &, const QUrl &)>(139, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 140, 2 }, { 0x80000000 | 4, 2 }, { 0x80000000 | 4, 141 },
        }}),
        // Slot 'slotItemLinkCreatedFromJob'
        QtMocHelpers::SlotData<void(KIO::Job *, const QUrl &, const QString &, const QUrl &)>(142, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 140, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::QString, 2 }, { 0x80000000 | 4, 141 },
        }}),
        // Slot 'slotIncreaseZoom'
        QtMocHelpers::SlotData<void()>(143, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDecreaseZoom'
        QtMocHelpers::SlotData<void()>(144, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwipeUp'
        QtMocHelpers::SlotData<void()>(145, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotItemCreated'
        QtMocHelpers::SlotData<void(const QUrl &)>(146, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'slotJobResult'
        QtMocHelpers::SlotData<void(KJob *)>(147, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 148, 149 },
        }}),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void(const KItemSet &, const KItemSet &)>(150, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 116, 20 }, { 0x80000000 | 116, 21 },
        }}),
        // Slot 'emitSelectionChangedSignal'
        QtMocHelpers::SlotData<void()>(151, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStatJobResult'
        QtMocHelpers::SlotData<void(KJob *)>(152, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 148, 149 },
        }}),
        // Slot 'updateSortFoldersFirst'
        QtMocHelpers::SlotData<void(bool)>(153, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Slot 'updateDefaultZoomLevel'
        QtMocHelpers::SlotData<void()>(154, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSortHiddenLast'
        QtMocHelpers::SlotData<void(bool)>(155, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'slotDeleteFileFinished'
        QtMocHelpers::SlotData<void(KJob *)>(156, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 148, 149 },
        }}),
        // Slot 'slotTrashFileFinished'
        QtMocHelpers::SlotData<void(KJob *)>(157, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 148, 149 },
        }}),
        // Slot 'slotRenamingResult'
        QtMocHelpers::SlotData<void(KJob *)>(158, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 148, 149 },
        }}),
        // Slot 'slotDirectoryLoadingStarted'
        QtMocHelpers::SlotData<void()>(159, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDirectoryLoadingCompleted'
        QtMocHelpers::SlotData<void()>(160, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDirectoryLoadingCanceled'
        QtMocHelpers::SlotData<void()>(161, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotItemsChanged'
        QtMocHelpers::SlotData<void()>(162, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSortOrderChangedByHeader'
        QtMocHelpers::SlotData<void(Qt::SortOrder, Qt::SortOrder)>(163, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 20 }, { 0x80000000 | 33, 21 },
        }}),
        // Slot 'slotSortRoleChangedByHeader'
        QtMocHelpers::SlotData<void(const QByteArray &, const QByteArray &)>(164, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 20 }, { QMetaType::QByteArray, 21 },
        }}),
        // Slot 'slotVisibleRolesChangedByHeader'
        QtMocHelpers::SlotData<void(const QList<QByteArray> &, const QList<QByteArray> &)>(165, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 20 }, { 0x80000000 | 40, 21 },
        }}),
        // Slot 'slotRoleEditingCanceled'
        QtMocHelpers::SlotData<void()>(166, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRoleEditingFinished'
        QtMocHelpers::SlotData<void(int, const QByteArray &, const QVariant &)>(167, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 114 }, { QMetaType::QByteArray, 30 }, { 0x80000000 | 168, 169 },
        }}),
        // Slot 'observeCreatedItem'
        QtMocHelpers::SlotData<void(const QUrl &)>(170, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'observeCreatedDirectory'
        QtMocHelpers::SlotData<void(const QUrl &)>(171, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'selectNextItem'
        QtMocHelpers::SlotData<void()>(172, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDirectoryRedirection'
        QtMocHelpers::SlotData<void(const QUrl &, const QUrl &)>(173, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 64 }, { 0x80000000 | 4, 65 },
        }}),
        // Slot 'slotTwoClicksRenamingTimerTimeout'
        QtMocHelpers::SlotData<void()>(174, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDirectoryLoadingCompletedAfterJob'
        QtMocHelpers::SlotData<void()>(175, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DolphinView, qt_meta_tag_ZN11DolphinViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DolphinView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DolphinViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DolphinViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DolphinViewE_t>.metaTypes,
    nullptr
} };

void DolphinView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DolphinView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activated(); break;
        case 1: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 2: _t->itemActivated((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 3: _t->requestPropertyDialog(); break;
        case 4: _t->fileMiddleClickActivated((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 5: _t->itemsActivated((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 6: _t->itemCountChanged(); break;
        case 7: _t->tabRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->activeTabRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 9: _t->windowRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<DolphinView::Mode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DolphinView::Mode>>(_a[2]))); break;
        case 11: _t->previewsShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->hiddenFilesShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->groupedSortingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->statusBarTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->sortRoleChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 16: _t->groupRoleChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 17: _t->sortOrderChanged((*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[1]))); break;
        case 18: _t->sortFoldersFirstChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->sortHiddenLastChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->visibleRolesChanged((*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2]))); break;
        case 21: _t->zoomLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 22: _t->requestItemInfo((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 23: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 24: _t->requestContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[4]))); break;
        case 25: _t->infoMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 27: _t->operationCompletedMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->showTypeAheadFeedback((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->directoryLoadingStarted(); break;
        case 30: _t->directoryLoadingCompleted(); break;
        case 31: _t->directoryLoadingCanceled(); break;
        case 32: _t->directoryLoadingProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->directorySortingProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->redirection((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 35: _t->urlIsFileError((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 36: _t->writeStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->goBackRequested(); break;
        case 38: _t->goForwardRequested(); break;
        case 39: _t->selectionModeChangeRequested((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->toggleActiveViewRequested(); break;
        case 41: _t->urlActivated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 42: _t->goUpRequested(); break;
        case 43: _t->fileItemsChanged((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 44: _t->currentDirectoryRemoved(); break;
        case 45: _t->clickViewBackground((*reinterpret_cast<std::add_pointer_t<Qt::MouseButton>>(_a[1]))); break;
        case 46: _t->doubleClickViewBackground((*reinterpret_cast<std::add_pointer_t<Qt::MouseButton>>(_a[1]))); break;
        case 47: _t->viewSettingsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: _t->reload(); break;
        case 49: _t->setUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 50: _t->selectAll(); break;
        case 51: _t->invertSelection(); break;
        case 52: _t->clearSelection(); break;
        case 53: _t->renameSelectedItems(); break;
        case 54: _t->trashSelectedItems(); break;
        case 55: _t->deleteSelectedItems(); break;
        case 56: _t->cutSelectedItemsToClipboard(); break;
        case 57: _t->copySelectedItemsToClipboard(); break;
        case 58: _t->copySelectedItems((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 59: _t->moveSelectedItems((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 60: _t->paste(); break;
        case 61: _t->pasteIntoFolder(); break;
        case 62: _t->copyPathToClipboard(); break;
        case 63: _t->duplicateSelectedItems(); break;
        case 64: _t->dropUrls((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[3]))); break;
        case 65: _t->stopLoading(); break;
        case 66: _t->updateViewState(); break;
        case 67: { bool _r = _t->isViewSettingsDefaults();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 68: _t->restoreViewSettingsToDefaults(); break;
        case 69: _t->activate(); break;
        case 70: _t->slotItemActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 71: _t->slotItemsActivated((*reinterpret_cast<std::add_pointer_t<KItemSet>>(_a[1]))); break;
        case 72: _t->slotItemMiddleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 73: _t->slotItemContextMenuRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 74: _t->slotViewContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 75: _t->slotHeaderContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 76: _t->slotHeaderColumnWidthChangeFinished((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 77: _t->slotSidePaddingWidthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 78: _t->slotItemHovered((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 79: _t->slotItemUnhovered((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 80: _t->slotItemDropEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QGraphicsSceneDragDropEvent*>>(_a[2]))); break;
        case 81: _t->slotModelChanged((*reinterpret_cast<std::add_pointer_t<KItemModelBase*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KItemModelBase*>>(_a[2]))); break;
        case 82: _t->slotMouseButtonPressed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::MouseButtons>>(_a[2]))); break;
        case 83: _t->slotSelectedItemTextPressed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 84: _t->slotItemCreatedFromJob((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 85: _t->slotItemLinkCreatedFromJob((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[4]))); break;
        case 86: _t->slotIncreaseZoom(); break;
        case 87: _t->slotDecreaseZoom(); break;
        case 88: _t->slotSwipeUp(); break;
        case 89: _t->slotItemCreated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 90: _t->slotJobResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 91: _t->slotSelectionChanged((*reinterpret_cast<std::add_pointer_t<KItemSet>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KItemSet>>(_a[2]))); break;
        case 92: _t->emitSelectionChangedSignal(); break;
        case 93: _t->slotStatJobResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 94: _t->updateSortFoldersFirst((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 95: _t->updateDefaultZoomLevel(); break;
        case 96: _t->updateSortHiddenLast((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 97: _t->slotDeleteFileFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 98: _t->slotTrashFileFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 99: _t->slotRenamingResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 100: _t->slotDirectoryLoadingStarted(); break;
        case 101: _t->slotDirectoryLoadingCompleted(); break;
        case 102: _t->slotDirectoryLoadingCanceled(); break;
        case 103: _t->slotItemsChanged(); break;
        case 104: _t->slotSortOrderChangedByHeader((*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[2]))); break;
        case 105: _t->slotSortRoleChangedByHeader((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 106: _t->slotVisibleRolesChangedByHeader((*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[2]))); break;
        case 107: _t->slotRoleEditingCanceled(); break;
        case 108: _t->slotRoleEditingFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 109: _t->observeCreatedItem((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 110: _t->observeCreatedDirectory((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 111: _t->selectNextItem(); break;
        case 112: _t->slotDirectoryRedirection((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 113: _t->slotTwoClicksRenamingTimerTimeout(); break;
        case 114: _t->onDirectoryLoadingCompletedAfterJob(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DolphinView::Mode >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 64:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 84:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 85:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 90:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 93:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 97:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 98:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 99:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 106:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::activated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QUrl & )>(_a, &DolphinView::urlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const KFileItem & )>(_a, &DolphinView::itemActivated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::requestPropertyDialog, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const KFileItem & )>(_a, &DolphinView::fileMiddleClickActivated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const KFileItemList & )>(_a, &DolphinView::itemsActivated, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::itemCountChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QUrl & )>(_a, &DolphinView::tabRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QUrl & )>(_a, &DolphinView::activeTabRequested, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QUrl & )>(_a, &DolphinView::windowRequested, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(DolphinView::Mode , DolphinView::Mode )>(_a, &DolphinView::modeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(bool )>(_a, &DolphinView::previewsShownChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(bool )>(_a, &DolphinView::hiddenFilesShownChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(bool )>(_a, &DolphinView::groupedSortingChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(QString )>(_a, &DolphinView::statusBarTextChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QByteArray & )>(_a, &DolphinView::sortRoleChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QByteArray & )>(_a, &DolphinView::groupRoleChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(Qt::SortOrder )>(_a, &DolphinView::sortOrderChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(bool )>(_a, &DolphinView::sortFoldersFirstChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(bool )>(_a, &DolphinView::sortHiddenLastChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QList<QByteArray> & , const QList<QByteArray> & )>(_a, &DolphinView::visibleRolesChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(int , int )>(_a, &DolphinView::zoomLevelChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const KFileItem & )>(_a, &DolphinView::requestItemInfo, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const KFileItemList & )>(_a, &DolphinView::selectionChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QPoint & , const KFileItem & , const KFileItemList & , const QUrl & )>(_a, &DolphinView::requestContextMenu, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QString & )>(_a, &DolphinView::infoMessage, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QString & , const int )>(_a, &DolphinView::errorMessage, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QString & )>(_a, &DolphinView::operationCompletedMessage, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QString & )>(_a, &DolphinView::showTypeAheadFeedback, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::directoryLoadingStarted, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::directoryLoadingCompleted, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::directoryLoadingCanceled, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(int )>(_a, &DolphinView::directoryLoadingProgress, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(int )>(_a, &DolphinView::directorySortingProgress, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QUrl & , const QUrl & )>(_a, &DolphinView::redirection, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QUrl & )>(_a, &DolphinView::urlIsFileError, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(bool )>(_a, &DolphinView::writeStateChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::goBackRequested, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::goForwardRequested, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(bool )>(_a, &DolphinView::selectionModeChangeRequested, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::toggleActiveViewRequested, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const QUrl & )>(_a, &DolphinView::urlActivated, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::goUpRequested, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(const KFileItemList & )>(_a, &DolphinView::fileItemsChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)()>(_a, &DolphinView::currentDirectoryRemoved, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(Qt::MouseButton )>(_a, &DolphinView::clickViewBackground, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(Qt::MouseButton )>(_a, &DolphinView::doubleClickViewBackground, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinView::*)(bool )>(_a, &DolphinView::viewSettingsChanged, 47))
            return;
    }
}

const QMetaObject *DolphinView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DolphinView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DolphinViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int DolphinView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 115)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 115;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 115)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 115;
    }
    return _id;
}

// SIGNAL 0
void DolphinView::activated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DolphinView::urlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DolphinView::itemActivated(const KFileItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DolphinView::requestPropertyDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DolphinView::fileMiddleClickActivated(const KFileItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DolphinView::itemsActivated(const KFileItemList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DolphinView::itemCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DolphinView::tabRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DolphinView::activeTabRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DolphinView::windowRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DolphinView::modeChanged(DolphinView::Mode _t1, DolphinView::Mode _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void DolphinView::previewsShownChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DolphinView::hiddenFilesShownChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DolphinView::groupedSortingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DolphinView::statusBarTextChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DolphinView::sortRoleChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DolphinView::groupRoleChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void DolphinView::sortOrderChanged(Qt::SortOrder _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void DolphinView::sortFoldersFirstChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void DolphinView::sortHiddenLastChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void DolphinView::visibleRolesChanged(const QList<QByteArray> & _t1, const QList<QByteArray> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2);
}

// SIGNAL 21
void DolphinView::zoomLevelChanged(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2);
}

// SIGNAL 22
void DolphinView::requestItemInfo(const KFileItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void DolphinView::selectionChanged(const KFileItemList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void DolphinView::requestContextMenu(const QPoint & _t1, const KFileItem & _t2, const KFileItemList & _t3, const QUrl & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 25
void DolphinView::infoMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void DolphinView::errorMessage(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2);
}

// SIGNAL 27
void DolphinView::operationCompletedMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void DolphinView::showTypeAheadFeedback(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void DolphinView::directoryLoadingStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void DolphinView::directoryLoadingCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void DolphinView::directoryLoadingCanceled()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void DolphinView::directoryLoadingProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void DolphinView::directorySortingProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1);
}

// SIGNAL 34
void DolphinView::redirection(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 34, nullptr, _t1, _t2);
}

// SIGNAL 35
void DolphinView::urlIsFileError(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1);
}

// SIGNAL 36
void DolphinView::writeStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1);
}

// SIGNAL 37
void DolphinView::goBackRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void DolphinView::goForwardRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void DolphinView::selectionModeChangeRequested(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1);
}

// SIGNAL 40
void DolphinView::toggleActiveViewRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void DolphinView::urlActivated(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 41, nullptr, _t1);
}

// SIGNAL 42
void DolphinView::goUpRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void DolphinView::fileItemsChanged(const KFileItemList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 43, nullptr, _t1);
}

// SIGNAL 44
void DolphinView::currentDirectoryRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void DolphinView::clickViewBackground(Qt::MouseButton _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 45, nullptr, _t1);
}

// SIGNAL 46
void DolphinView::doubleClickViewBackground(Qt::MouseButton _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 46, nullptr, _t1);
}

// SIGNAL 47
void DolphinView::viewSettingsChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 47, nullptr, _t1);
}
QT_WARNING_POP
