/****************************************************************************
** Meta object code from reading C++ file 'dolphinmainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../dolphin-26.07.80/src/dolphinmainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dolphinmainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DolphinMainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto DolphinMainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN17DolphinMainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DolphinMainWindow",
        "D-Bus Interface",
        "org.kde.dolphin.MainWindow",
        "selectionChanged",
        "",
        "KFileItemList",
        "selection",
        "urlChanged",
        "QUrl",
        "url",
        "urlRefreshed",
        "requestItemInfo",
        "KFileItem",
        "item",
        "fileItemsChanged",
        "changedFileItems",
        "settingsChanged",
        "openDirectories",
        "dirs",
        "splitView",
        "openFiles",
        "files",
        "activateWindow",
        "activationToken",
        "isActiveWindow",
        "isUrlOpen",
        "isItemVisibleInAnyView",
        "urlOfItem",
        "pasteIntoFolder",
        "changeUrl",
        "slotTerminalDirectoryChanged",
        "quit",
        "openNewTab",
        "DolphinTabPage*",
        "openNewTabAndActivate",
        "openNewWindow",
        "slotSplitViewChanged",
        "slotTabBarChanged",
        "saveNewToolbarConfig",
        "refreshViews",
        "updateNewMenu",
        "createDirectory",
        "createFile",
        "showErrorMessage",
        "message",
        "slotUndoAvailable",
        "available",
        "slotUndoTextChanged",
        "text",
        "undo",
        "slotRedoAvailable",
        "slotRedoTextChanged",
        "redo",
        "cut",
        "copy",
        "paste",
        "find",
        "updateSearchAction",
        "updatePasteAction",
        "slotSetSelectionMode",
        "enabled",
        "SelectionMode::BottomBar::Contents",
        "bottomBarContents",
        "selectAll",
        "invertSelection",
        "toggleSplitView",
        "popoutSplitView",
        "toggleSplitStash",
        "copyToInactiveSplitView",
        "moveToInactiveSplitView",
        "reloadView",
        "stopLoading",
        "enableStopAction",
        "disableStopAction",
        "toggleSelectionMode",
        "showFilterBar",
        "toggleFilterBar",
        "toggleEditLocation",
        "replaceLocation",
        "togglePanelLockState",
        "slotTerminalPanelVisibilityChanged",
        "visible",
        "slotPlacesPanelVisibilityChanged",
        "goBack",
        "goForward",
        "goUp",
        "goHome",
        "goBackInNewTab",
        "goForwardInNewTab",
        "goUpInNewTab",
        "goHomeInNewTab",
        "compareFiles",
        "toggleShowMenuBar",
        "updateOpenPreferredSearchToolAction",
        "openPreferredSearchTool",
        "openTerminal",
        "openTerminalHere",
        "openTerminalJob",
        "toggleTerminalPanelFocus",
        "togglePlacesPanelFocus",
        "editSettings",
        "slotEditableStateChanged",
        "editable",
        "slotSelectionChanged",
        "updateHistory",
        "updateFilterBarAction",
        "show",
        "openNewMainWindow",
        "openNewActivatedTab",
        "addToPlaces",
        "openInNewTab",
        "openInNewWindow",
        "openInSplitView",
        "showTarget",
        "handleUrl",
        "slotWriteStateChanged",
        "isFolderWritable",
        "openContextMenu",
        "QPoint",
        "pos",
        "selectedItems",
        "updateHamburgerMenu",
        "slotPlaceActivated",
        "activeViewChanged",
        "DolphinViewContainer*",
        "viewContainer",
        "closedTabsCountChanged",
        "count",
        "tabCountChanged",
        "updateWindowTitle",
        "slotStorageTearDownFromPlacesRequested",
        "mountPath",
        "slotStorageTearDownExternallyRequested",
        "slotDirectoryLoadingCompleted",
        "slotToolBarActionMiddleClicked",
        "QAction*",
        "action",
        "slotAboutToShowBackPopupMenu",
        "slotGoBack",
        "slotBackForwardActionMiddleClicked",
        "slotAboutToShowForwardPopupMenu",
        "slotGoForward",
        "slotKeyBindings",
        "slotSaveSession",
        "slotClickViewBackground"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(const KFileItemList &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'urlRefreshed'
        QtMocHelpers::SignalData<void(const QUrl &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'requestItemInfo'
        QtMocHelpers::SignalData<void(const KFileItem &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'fileItemsChanged'
        QtMocHelpers::SignalData<void(const KFileItemList &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 15 },
        }}),
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openDirectories'
        QtMocHelpers::SlotData<void(const QStringList &, bool)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'openFiles'
        QtMocHelpers::SlotData<void(const QStringList &, bool)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 21 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'activateWindow'
        QtMocHelpers::SlotData<void(const QString &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'isActiveWindow'
        QtMocHelpers::SlotData<bool()>(24, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isUrlOpen'
        QtMocHelpers::SlotData<bool(const QString &)>(25, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'isItemVisibleInAnyView'
        QtMocHelpers::SlotData<bool(const QString &)>(26, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'pasteIntoFolder'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotTerminalDirectoryChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'quit'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openNewTab'
        QtMocHelpers::SlotData<DolphinTabPage *(const QUrl &)>(32, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'openNewTabAndActivate'
        QtMocHelpers::SlotData<void(const QUrl &)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'openNewWindow'
        QtMocHelpers::SlotData<void(const QUrl &)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotSplitViewChanged'
        QtMocHelpers::SlotData<void()>(36, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTabBarChanged'
        QtMocHelpers::SlotData<void()>(37, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveNewToolbarConfig'
        QtMocHelpers::SlotData<void()>(38, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'refreshViews'
        QtMocHelpers::SlotData<void()>(39, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateNewMenu'
        QtMocHelpers::SlotData<void()>(40, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createDirectory'
        QtMocHelpers::SlotData<void()>(41, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createFile'
        QtMocHelpers::SlotData<void()>(42, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showErrorMessage'
        QtMocHelpers::SlotData<void(const QString &)>(43, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'slotUndoAvailable'
        QtMocHelpers::SlotData<void(bool)>(45, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 46 },
        }}),
        // Slot 'slotUndoTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(47, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(49, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRedoAvailable'
        QtMocHelpers::SlotData<void(bool)>(50, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 46 },
        }}),
        // Slot 'slotRedoTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(51, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(52, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(53, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(55, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'find'
        QtMocHelpers::SlotData<void()>(56, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSearchAction'
        QtMocHelpers::SlotData<void()>(57, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePasteAction'
        QtMocHelpers::SlotData<void()>(58, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetSelectionMode'
        QtMocHelpers::SlotData<void(bool, SelectionMode::BottomBar::Contents)>(59, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 60 }, { 0x80000000 | 61, 62 },
        }}),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(63, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'invertSelection'
        QtMocHelpers::SlotData<void()>(64, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleSplitView'
        QtMocHelpers::SlotData<void()>(65, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'popoutSplitView'
        QtMocHelpers::SlotData<void()>(66, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleSplitStash'
        QtMocHelpers::SlotData<void()>(67, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copyToInactiveSplitView'
        QtMocHelpers::SlotData<void()>(68, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveToInactiveSplitView'
        QtMocHelpers::SlotData<void()>(69, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadView'
        QtMocHelpers::SlotData<void()>(70, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopLoading'
        QtMocHelpers::SlotData<void()>(71, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableStopAction'
        QtMocHelpers::SlotData<void()>(72, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'disableStopAction'
        QtMocHelpers::SlotData<void()>(73, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleSelectionMode'
        QtMocHelpers::SlotData<void()>(74, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showFilterBar'
        QtMocHelpers::SlotData<void()>(75, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFilterBar'
        QtMocHelpers::SlotData<void()>(76, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleEditLocation'
        QtMocHelpers::SlotData<void()>(77, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'replaceLocation'
        QtMocHelpers::SlotData<void()>(78, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'togglePanelLockState'
        QtMocHelpers::SlotData<void()>(79, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTerminalPanelVisibilityChanged'
        QtMocHelpers::SlotData<void(bool)>(80, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 81 },
        }}),
        // Slot 'slotPlacesPanelVisibilityChanged'
        QtMocHelpers::SlotData<void(bool)>(82, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 81 },
        }}),
        // Slot 'goBack'
        QtMocHelpers::SlotData<void()>(83, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goForward'
        QtMocHelpers::SlotData<void()>(84, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goUp'
        QtMocHelpers::SlotData<void()>(85, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goHome'
        QtMocHelpers::SlotData<void()>(86, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goBackInNewTab'
        QtMocHelpers::SlotData<void()>(87, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goForwardInNewTab'
        QtMocHelpers::SlotData<void()>(88, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goUpInNewTab'
        QtMocHelpers::SlotData<void()>(89, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goHomeInNewTab'
        QtMocHelpers::SlotData<void()>(90, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'compareFiles'
        QtMocHelpers::SlotData<void()>(91, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleShowMenuBar'
        QtMocHelpers::SlotData<void()>(92, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateOpenPreferredSearchToolAction'
        QtMocHelpers::SlotData<void()>(93, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openPreferredSearchTool'
        QtMocHelpers::SlotData<void()>(94, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openTerminal'
        QtMocHelpers::SlotData<void()>(95, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openTerminalHere'
        QtMocHelpers::SlotData<void()>(96, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openTerminalJob'
        QtMocHelpers::SlotData<void(const QUrl &)>(97, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'toggleTerminalPanelFocus'
        QtMocHelpers::SlotData<void()>(98, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'togglePlacesPanelFocus'
        QtMocHelpers::SlotData<void()>(99, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editSettings'
        QtMocHelpers::SlotData<void()>(100, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditableStateChanged'
        QtMocHelpers::SlotData<void(bool)>(101, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 102 },
        }}),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(103, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'updateHistory'
        QtMocHelpers::SlotData<void()>(104, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFilterBarAction'
        QtMocHelpers::SlotData<void(bool)>(105, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 106 },
        }}),
        // Slot 'openNewMainWindow'
        QtMocHelpers::SlotData<void()>(107, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openNewActivatedTab'
        QtMocHelpers::SlotData<void()>(108, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addToPlaces'
        QtMocHelpers::SlotData<void()>(109, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openInNewTab'
        QtMocHelpers::SlotData<void()>(110, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openInNewWindow'
        QtMocHelpers::SlotData<void()>(111, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openInSplitView'
        QtMocHelpers::SlotData<void(const QUrl &)>(112, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'showTarget'
        QtMocHelpers::SlotData<void()>(113, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(114, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotWriteStateChanged'
        QtMocHelpers::SlotData<void(bool)>(115, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 116 },
        }}),
        // Slot 'openContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &, const KFileItem &, const KFileItemList &, const QUrl &)>(117, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 118, 119 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 5, 120 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'updateHamburgerMenu'
        QtMocHelpers::SlotData<void()>(121, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPlaceActivated'
        QtMocHelpers::SlotData<void(const QUrl &)>(122, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'activeViewChanged'
        QtMocHelpers::SlotData<void(DolphinViewContainer *)>(123, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 124, 125 },
        }}),
        // Slot 'closedTabsCountChanged'
        QtMocHelpers::SlotData<void(unsigned int)>(126, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 127 },
        }}),
        // Slot 'tabCountChanged'
        QtMocHelpers::SlotData<void(int)>(128, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 127 },
        }}),
        // Slot 'updateWindowTitle'
        QtMocHelpers::SlotData<void()>(129, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStorageTearDownFromPlacesRequested'
        QtMocHelpers::SlotData<void(const QString &)>(130, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 131 },
        }}),
        // Slot 'slotStorageTearDownExternallyRequested'
        QtMocHelpers::SlotData<void(const QString &)>(132, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 131 },
        }}),
        // Slot 'slotDirectoryLoadingCompleted'
        QtMocHelpers::SlotData<void()>(133, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToolBarActionMiddleClicked'
        QtMocHelpers::SlotData<void(QAction *)>(134, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 135, 136 },
        }}),
        // Slot 'slotAboutToShowBackPopupMenu'
        QtMocHelpers::SlotData<void()>(137, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGoBack'
        QtMocHelpers::SlotData<void(QAction *)>(138, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 135, 136 },
        }}),
        // Slot 'slotBackForwardActionMiddleClicked'
        QtMocHelpers::SlotData<void(QAction *)>(139, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 135, 136 },
        }}),
        // Slot 'slotAboutToShowForwardPopupMenu'
        QtMocHelpers::SlotData<void()>(140, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGoForward'
        QtMocHelpers::SlotData<void(QAction *)>(141, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 135, 136 },
        }}),
        // Slot 'slotKeyBindings'
        QtMocHelpers::SlotData<void()>(142, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveSession'
        QtMocHelpers::SlotData<void()>(143, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClickViewBackground'
        QtMocHelpers::SlotData<void()>(144, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DolphinMainWindow, qt_meta_tag_ZN17DolphinMainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DolphinMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DolphinMainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DolphinMainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DolphinMainWindowE_t>.metaTypes,
    nullptr
} };

void DolphinMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DolphinMainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 1: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 2: _t->urlRefreshed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->requestItemInfo((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 4: _t->fileItemsChanged((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 5: _t->settingsChanged(); break;
        case 6: _t->openDirectories((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 7: _t->openFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->activateWindow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: { bool _r = _t->isActiveWindow();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->isUrlOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->isItemVisibleInAnyView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->pasteIntoFolder(); break;
        case 13: _t->changeUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 14: _t->slotTerminalDirectoryChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 15: _t->quit(); break;
        case 16: { DolphinTabPage* _r = _t->openNewTab((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DolphinTabPage**>(_a[0]) = std::move(_r); }  break;
        case 17: _t->openNewTabAndActivate((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 18: _t->openNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 19: _t->slotSplitViewChanged(); break;
        case 20: _t->slotTabBarChanged(); break;
        case 21: _t->saveNewToolbarConfig(); break;
        case 22: _t->refreshViews(); break;
        case 23: _t->updateNewMenu(); break;
        case 24: _t->createDirectory(); break;
        case 25: _t->createFile(); break;
        case 26: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->slotUndoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->slotUndoTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->undo(); break;
        case 30: _t->slotRedoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->slotRedoTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->redo(); break;
        case 33: _t->cut(); break;
        case 34: _t->copy(); break;
        case 35: _t->paste(); break;
        case 36: _t->find(); break;
        case 37: _t->updateSearchAction(); break;
        case 38: _t->updatePasteAction(); break;
        case 39: _t->slotSetSelectionMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SelectionMode::BottomBar::Contents>>(_a[2]))); break;
        case 40: _t->selectAll(); break;
        case 41: _t->invertSelection(); break;
        case 42: _t->toggleSplitView(); break;
        case 43: _t->popoutSplitView(); break;
        case 44: _t->toggleSplitStash(); break;
        case 45: _t->copyToInactiveSplitView(); break;
        case 46: _t->moveToInactiveSplitView(); break;
        case 47: _t->reloadView(); break;
        case 48: _t->stopLoading(); break;
        case 49: _t->enableStopAction(); break;
        case 50: _t->disableStopAction(); break;
        case 51: _t->toggleSelectionMode(); break;
        case 52: _t->showFilterBar(); break;
        case 53: _t->toggleFilterBar(); break;
        case 54: _t->toggleEditLocation(); break;
        case 55: _t->replaceLocation(); break;
        case 56: _t->togglePanelLockState(); break;
        case 57: _t->slotTerminalPanelVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 58: _t->slotPlacesPanelVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 59: _t->goBack(); break;
        case 60: _t->goForward(); break;
        case 61: _t->goUp(); break;
        case 62: _t->goHome(); break;
        case 63: _t->goBackInNewTab(); break;
        case 64: _t->goForwardInNewTab(); break;
        case 65: _t->goUpInNewTab(); break;
        case 66: _t->goHomeInNewTab(); break;
        case 67: _t->compareFiles(); break;
        case 68: _t->toggleShowMenuBar(); break;
        case 69: _t->updateOpenPreferredSearchToolAction(); break;
        case 70: _t->openPreferredSearchTool(); break;
        case 71: _t->openTerminal(); break;
        case 72: _t->openTerminalHere(); break;
        case 73: _t->openTerminalJob((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 74: _t->toggleTerminalPanelFocus(); break;
        case 75: _t->togglePlacesPanelFocus(); break;
        case 76: _t->editSettings(); break;
        case 77: _t->slotEditableStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 78: _t->slotSelectionChanged((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 79: _t->updateHistory(); break;
        case 80: _t->updateFilterBarAction((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 81: _t->openNewMainWindow(); break;
        case 82: _t->openNewActivatedTab(); break;
        case 83: _t->addToPlaces(); break;
        case 84: _t->openInNewTab(); break;
        case 85: _t->openInNewWindow(); break;
        case 86: _t->openInSplitView((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 87: _t->showTarget(); break;
        case 88: _t->handleUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 89: _t->slotWriteStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 90: _t->openContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[4]))); break;
        case 91: _t->updateHamburgerMenu(); break;
        case 92: _t->slotPlaceActivated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 93: _t->activeViewChanged((*reinterpret_cast<std::add_pointer_t<DolphinViewContainer*>>(_a[1]))); break;
        case 94: _t->closedTabsCountChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 95: _t->tabCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 96: _t->updateWindowTitle(); break;
        case 97: _t->slotStorageTearDownFromPlacesRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 98: _t->slotStorageTearDownExternallyRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 99: _t->slotDirectoryLoadingCompleted(); break;
        case 100: _t->slotToolBarActionMiddleClicked((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 101: _t->slotAboutToShowBackPopupMenu(); break;
        case 102: _t->slotGoBack((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 103: _t->slotBackForwardActionMiddleClicked((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 104: _t->slotAboutToShowForwardPopupMenu(); break;
        case 105: _t->slotGoForward((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 106: _t->slotKeyBindings(); break;
        case 107: _t->slotSaveSession(); break;
        case 108: _t->slotClickViewBackground(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 90:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 100:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 102:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 103:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 105:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DolphinMainWindow::*)(const KFileItemList & )>(_a, &DolphinMainWindow::selectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinMainWindow::*)(const QUrl & )>(_a, &DolphinMainWindow::urlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinMainWindow::*)(const QUrl & )>(_a, &DolphinMainWindow::urlRefreshed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinMainWindow::*)(const KFileItem & )>(_a, &DolphinMainWindow::requestItemInfo, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinMainWindow::*)(const KFileItemList & )>(_a, &DolphinMainWindow::fileItemsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DolphinMainWindow::*)()>(_a, &DolphinMainWindow::settingsChanged, 5))
            return;
    }
}

const QMetaObject *DolphinMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DolphinMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DolphinMainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int DolphinMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 109)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 109;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 109)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 109;
    }
    return _id;
}

// SIGNAL 0
void DolphinMainWindow::selectionChanged(const KFileItemList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DolphinMainWindow::urlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DolphinMainWindow::urlRefreshed(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DolphinMainWindow::requestItemInfo(const KFileItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DolphinMainWindow::fileItemsChanged(const KFileItemList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DolphinMainWindow::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
