// This file is generated by kconfig_compiler_kf6 from dolphin_versioncontrolsettings.kcfg.
// All changes you do to this file will be lost.
#ifndef VERSIONCONTROLSETTINGS_H
#define VERSIONCONTROLSETTINGS_H

#include <dolphin_export.h>

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class DOLPHIN_EXPORT VersionControlSettings : public KConfigSkeleton
{
  public:

    static VersionControlSettings *self();
    ~VersionControlSettings() override;

    /**
      Set Enabled plugins
    */
    static
    void setEnabledPlugins( const QStringList & v )
    {
      if (!self()->isEnabledPluginsImmutable())
        self()->mEnabledPlugins = v;
    }

    /**
      Get Enabled plugins
    */
    static
    QStringList enabledPlugins()
    {
      return self()->mEnabledPlugins;
    }

    /**
      Is Enabled plugins Immutable
    */
    static
    bool isEnabledPluginsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enabledPlugins" ) );
    }

  protected:
    VersionControlSettings();
    friend class VersionControlSettingsHelper;


    // VersionControl
    QStringList mEnabledPlugins;
};

#endif

